==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/KafkaBridgeSpecBuilder.java <==
package io.strimzi.api.kafka.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaBridgeSpecBuilder extends KafkaBridgeSpecFluentImpl<KafkaBridgeSpecBuilder> implements VisitableBuilder<KafkaBridgeSpec,KafkaBridgeSpecBuilder>{

    KafkaBridgeSpecFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaBridgeSpecBuilder(){
            this(true);
    }
    public KafkaBridgeSpecBuilder(Boolean validationEnabled){
            this(new KafkaBridgeSpec(), validationEnabled);
    }
    public KafkaBridgeSpecBuilder(KafkaBridgeSpecFluent<?> fluent){
            this(fluent, true);
    }
    public KafkaBridgeSpecBuilder(KafkaBridgeSpecFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new KafkaBridgeSpec(), validationEnabled);
    }
    public KafkaBridgeSpecBuilder(KafkaBridgeSpecFluent<?> fluent,KafkaBridgeSpec instance){
            this(fluent, instance, true);
    }
    public KafkaBridgeSpecBuilder(KafkaBridgeSpecFluent<?> fluent,KafkaBridgeSpec instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withReplicas(instance.getReplicas());

            fluent.withImage(instance.getImage());

            fluent.withHttp(instance.getHttp());

            fluent.withBootstrapServers(instance.getBootstrapServers());

            fluent.withTls(instance.getTls());

            fluent.withAuthentication(instance.getAuthentication());

            fluent.withConsumer(instance.getConsumer());

            fluent.withProducer(instance.getProducer());

            fluent.withResources(instance.getResources());

            fluent.withJvmOptions(instance.getJvmOptions());

            fluent.withLogging(instance.getLogging());

            fluent.withMetrics(instance.getMetrics());

            fluent.withLivenessProbe(instance.getLivenessProbe());

            fluent.withReadinessProbe(instance.getReadinessProbe());

            fluent.withTemplate(instance.getTemplate());

            fluent.withTracing(instance.getTracing());

            this.validationEnabled = validationEnabled; 
    }
    public KafkaBridgeSpecBuilder(KafkaBridgeSpec instance){
            this(instance,true);
    }
    public KafkaBridgeSpecBuilder(KafkaBridgeSpec instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withReplicas(instance.getReplicas());

            this.withImage(instance.getImage());

            this.withHttp(instance.getHttp());

            this.withBootstrapServers(instance.getBootstrapServers());

            this.withTls(instance.getTls());

            this.withAuthentication(instance.getAuthentication());

            this.withConsumer(instance.getConsumer());

            this.withProducer(instance.getProducer());

            this.withResources(instance.getResources());

            this.withJvmOptions(instance.getJvmOptions());

            this.withLogging(instance.getLogging());

            this.withMetrics(instance.getMetrics());

            this.withLivenessProbe(instance.getLivenessProbe());

            this.withReadinessProbe(instance.getReadinessProbe());

            this.withTemplate(instance.getTemplate());

            this.withTracing(instance.getTracing());

            this.validationEnabled = validationEnabled; 
    }

    public KafkaBridgeSpec build(){
            KafkaBridgeSpec buildable = new KafkaBridgeSpec();
            buildable.setReplicas(fluent.getReplicas());
            buildable.setImage(fluent.getImage());
            buildable.setHttp(fluent.getHttp());
            buildable.setBootstrapServers(fluent.getBootstrapServers());
            buildable.setTls(fluent.getTls());
            buildable.setAuthentication(fluent.getAuthentication());
            buildable.setConsumer(fluent.getConsumer());
            buildable.setProducer(fluent.getProducer());
            buildable.setResources(fluent.getResources());
            buildable.setJvmOptions(fluent.getJvmOptions());
            buildable.setLogging(fluent.getLogging());
            buildable.setMetrics(fluent.getMetrics());
            buildable.setLivenessProbe(fluent.getLivenessProbe());
            buildable.setReadinessProbe(fluent.getReadinessProbe());
            buildable.setTemplate(fluent.getTemplate());
            buildable.setTracing(fluent.getTracing());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            KafkaBridgeSpecBuilder that = (KafkaBridgeSpecBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/KafkaBridgeSpecBuilder.java <==
package io.strimzi.api.kafka.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaBridgeSpecBuilder extends KafkaBridgeSpecFluentImpl<KafkaBridgeSpecBuilder> implements VisitableBuilder<KafkaBridgeSpec,KafkaBridgeSpecBuilder>{

    KafkaBridgeSpecFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaBridgeSpecBuilder(){
            this(true);
    }
    public KafkaBridgeSpecBuilder(Boolean validationEnabled){
            this(new KafkaBridgeSpec(), validationEnabled);
    }
    public KafkaBridgeSpecBuilder(KafkaBridgeSpecFluent<?> fluent){
            this(fluent, true);
    }
    public KafkaBridgeSpecBuilder(KafkaBridgeSpecFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new KafkaBridgeSpec(), validationEnabled);
    }
    public KafkaBridgeSpecBuilder(KafkaBridgeSpecFluent<?> fluent,KafkaBridgeSpec instance){
            this(fluent, instance, true);
    }
    public KafkaBridgeSpecBuilder(KafkaBridgeSpecFluent<?> fluent,KafkaBridgeSpec instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withReplicas(instance.getReplicas());

            fluent.withImage(instance.getImage());

            fluent.withHttp(instance.getHttp());

            fluent.withBootstrapServers(instance.getBootstrapServers());

            fluent.withTls(instance.getTls());

            fluent.withAuthentication(instance.getAuthentication());

            fluent.withConsumer(instance.getConsumer());

            fluent.withProducer(instance.getProducer());

            fluent.withResources(instance.getResources());

            fluent.withJvmOptions(instance.getJvmOptions());

            fluent.withLogging(instance.getLogging());

            fluent.withEnableMetrics(instance.getEnableMetrics());

            fluent.withLivenessProbe(instance.getLivenessProbe());

            fluent.withReadinessProbe(instance.getReadinessProbe());

            fluent.withTemplate(instance.getTemplate());

            fluent.withTracing(instance.getTracing());

            this.validationEnabled = validationEnabled; 
    }
    public KafkaBridgeSpecBuilder(KafkaBridgeSpec instance){
            this(instance,true);
    }
    public KafkaBridgeSpecBuilder(KafkaBridgeSpec instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withReplicas(instance.getReplicas());

            this.withImage(instance.getImage());

            this.withHttp(instance.getHttp());

            this.withBootstrapServers(instance.getBootstrapServers());

            this.withTls(instance.getTls());

            this.withAuthentication(instance.getAuthentication());

            this.withConsumer(instance.getConsumer());

            this.withProducer(instance.getProducer());

            this.withResources(instance.getResources());

            this.withJvmOptions(instance.getJvmOptions());

            this.withLogging(instance.getLogging());

            this.withEnableMetrics(instance.getEnableMetrics());

            this.withLivenessProbe(instance.getLivenessProbe());

            this.withReadinessProbe(instance.getReadinessProbe());

            this.withTemplate(instance.getTemplate());

            this.withTracing(instance.getTracing());

            this.validationEnabled = validationEnabled; 
    }

    public KafkaBridgeSpec build(){
            KafkaBridgeSpec buildable = new KafkaBridgeSpec();
            buildable.setReplicas(fluent.getReplicas());
            buildable.setImage(fluent.getImage());
            buildable.setHttp(fluent.getHttp());
            buildable.setBootstrapServers(fluent.getBootstrapServers());
            buildable.setTls(fluent.getTls());
            buildable.setAuthentication(fluent.getAuthentication());
            buildable.setConsumer(fluent.getConsumer());
            buildable.setProducer(fluent.getProducer());
            buildable.setResources(fluent.getResources());
            buildable.setJvmOptions(fluent.getJvmOptions());
            buildable.setLogging(fluent.getLogging());
            buildable.setEnableMetrics(fluent.isEnableMetrics());
            buildable.setLivenessProbe(fluent.getLivenessProbe());
            buildable.setReadinessProbe(fluent.getReadinessProbe());
            buildable.setTemplate(fluent.getTemplate());
            buildable.setTracing(fluent.getTracing());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            KafkaBridgeSpecBuilder that = (KafkaBridgeSpecBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
